Learn R Programming

broman (version 0.68-2)

mypairs: My scatterplot matrix

Description

A matrix of scatterplots is produced; it's similar to pairs, but with only the upper triangle is made.

Usage

mypairs(x, ...)

Arguments

x

A numeric matrix or data frame.

...

Passed to the plot function.

Value

None.

Details

This is like the function pairs, but only the upper triangle is produced.

See Also

pairs

Examples

Run this code
# NOT RUN {
v <- rbind(c(1,0.5,0.2),c(0.5,1,0.9),c(0.2,0.9,1))
x <- rmvn(500, rep(5,3), v)
mypairs(x, col=sample(c("blue","red"), 500, repl=TRUE))

# }

Run the code above in your browser using DataLab