Learn R Programming

broman (version 0.98)

rmvn: Simulate multivariate normal

Description

Simulate from a multivariate normal distribution.

Usage

rmvn(n, mu = 0, V = matrix(1))

Value

A matrix of size n x length(mu). Each row corresponds to a separate replicate.

Arguments

n

Number of simulation replicates.

mu

Mean vector.

V

Variance-covariance matrix. If a single number, we take it to be the correlation between all pairs, in which case the variances are taken to be 1.

Details

Uses the Cholesky decomposition of the matrix V, obtained by base::chol().

See Also

Examples

Run this code
x <- rmvn(100, c(1,2),matrix(c(1,1,1,4),ncol=2))

Run the code above in your browser using DataLab