powered by
Creates a plot of the crayon colors in brocolors()
brocolors()
plot_crayons( colors = NULL, method2order = c("hsv", "cluster"), cex = NULL, mar = rep(0.1, 4), bg = "white", fg = "black", border = FALSE )
None
Set of colors to display, by name or RGB code; must be a subset of the crayons() colors.
crayons()
method to order colors ("hsv" or "cluster")
"hsv"
"cluster"
character expansion for the text
margin paramaters; vector of length 4 (see graphics::par())
graphics::par()
Background color
Foreground color (for text and box outlines)
If TRUE, plot a border around each rectangle
https://en.wikipedia.org/wiki/List_of_Crayola_crayon_colors
plot_crayons() plot_crayons("blue", cex=1) # plot just those that match "blue" plot_crayons("green", cex=1) # plot just those that match "green"
Run the code above in your browser using DataLab